--[[
 WebTV Setup Plugin
 
 Copyright (C) 2016 Celeburdi (intm@freestart.hu) from coolstream.to
 
  
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 Install:
   copy webtvsetup.* files to /var/tuxbox/plugins + (Reload plugins)
  
 Start:
   blue key -> WebTV Setup -> Select host and setup
   
 History
  2016.11.20 v0.1 Initial release

]]

local pluginver = {
 name="WebTV Setup",
 version = "0.1",
}

local n = neutrino()
local confpath = "/var/tuxbox/config/"
local locale = {}
local conf={}
 
function info(infotxt,captxt)
  if captxt==nil then
    captxt=locale.info
  end
	local h = hintbox.new{caption=captxt, text=infotxt}
	h:paint()
	repeat
		msg, data = n:GetInput(500)
	until msg == RC.ok or msg == RC.home
	h:hide()
end

function locale_english()
	locale={
    info = "Information",
    login = "Login",
    loginhint = "Enter Login",
    password = "Password",
    passwordhint = "Enter password",
    quality = "Quality",
    qualityhint = "Choose preferred quality",
    none = "none",
    low = "low",
    mid = "mid",
    high = "high",
    highplus = "high+"
  }
end

function init()
  locale_english()
end

function mainmenu()
  step=nil
  mm:exec()
end

function qualitytoname(n)
  local t={locale.low,locale.mid,locale.high,locale.highplus}
  local v=t[n]
  if v==nil then return locale.none end
  return v
end

function qualityfromname(s)
  local t={
   [locale.none]=0,
   [locale.low]=1,
   [locale.mid]=2,
   [locale.high]=3,
   [locale.highplus]=4}
  local v=t[s]
  if v==nil then return locale.none end
  return v
end

function setvar(k, v)
	conf[k]=v
	conf.changed = true
end

function setqualityvar(k, v)
  conf[k]=qualityfromname(v)
	conf.changed = true
end

function dosetup(t,fn)
  local cfn=confpath .. fn .. ".conf" 
  do
    local cf=configfile.new()
    cf:loadConfig(cfn)
    conf={
      changed=false,
      login=cf:getString("login", ""),
      password=cf:getString("password",""),
      quality=cf:getInt32("quality",3)
    }
  end  
  local m=menu.new{name=t,icon="icon_red"}
	m:addItem{type="back"}
	m:addItem{type="separatorline"}
  m:addItem{type="keyboardinput",action="setvar", id="login", name=locale.login, value=conf.login,
    directkey=RC["1"],hint_icon="hint_service",hint=locale.loginhint}
  m:addItem{type="keyboardinput",action="setvar", id="password", name=locale.password, value=conf.password,
    directkey=RC["2"],hint_icon="hint_service",hint=locale.passwordhint}
  m:addItem{type="chooser", action="setqualityvar", id="quality",
    options={locale.none, locale.low, locale.mid, locale.high, locale.highplus},
    value=qualitytoname(conf.quality), name=locale.quality,
    directkey=RC["3"],hint_icon="hint_service",hint=locale.qualityhint}
  m:exec()
  step=mainmenu
  if conf.changed then
    os.execute("rm /tmp/" .. fn .. ".cks")
    cf=configfile.new()
    cf:setString("login",conf.login)
    cf:setString("password",conf.password)
    cf:setInt32("quality",conf.quality)
    cf:saveConfig(cfn)
  end
end

function filmonsetup()
  dosetup("Filmon Setup","filmon")
end

function ustvnowsetup()
  dosetup("USTVnow Setup","ustvnow")
end

function setstep(f)
  step=_G[f]
  return MENU_RETURN["EXIT_ALL"]
end

--Main
init()
mm=menu.new{name=pluginver.name,icon=menuicon}
mm:addKey{directkey=RC["info"], action="info", id=pluginver.name .. ' ' .. pluginver.version}
mm:addItem{type="back"}
mm:addItem{type="separatorline"}
--mm:addItem{type="forwarder",name="Filmon",action="setstep",id="filmonsetup"}
mm:addItem{type="forwarder",name="USTVnow",action="setstep",id="ustvnowsetup"}
step=mainmenu;
repeat
  step()
until step==nil
